<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="2.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
    <!--tested on Oxygen with Saxon-PE 9.9.1.7-->
    <xsl:param name="AUDIO">
        <xsl:value-of select="//timeline/@corresp"/>
        <!--alternative <xsl:value-of select="//recordingStmt/recording/media/@url"/>-->
    </xsl:param>
    <xsl:param name="TITLE">
        <xsl:choose>
            <!-- title/@sub is the title of the transcript, title/@main is the title of the corpus  -->
            <xsl:when test="//title/@type = 'sub'">
                <xsl:value-of select="//title[@type = 'sub']"/>
            </xsl:when>
        </xsl:choose>
    </xsl:param>
    <!-- title/@sub is the title of the transcript, title/@main is the title of the corpus  -->
    <xsl:param name="CORPUSTITLE">
        <xsl:choose>

            <xsl:when test="//title/@type = 'main'">
                <xsl:value-of select="//title[@type = 'main']"/>
            </xsl:when>
        </xsl:choose>
    </xsl:param>
    <xsl:template match="/">
        <html>         
            <head>
                <link href="../css/font-awesome.css" rel="stylesheet"/>
                <link rel="stylesheet" href="../css/bootstrap.min.css"/>
                <link rel="stylesheet" href="../css/transcripts.css"/>
               <!-- <style type="text/css">
                </style>-->
               <!-- <script src="https://ajax.googleapis.com/ajax/libs/jquery/3.5.1/jquery.min.js"/>-->
                <script src="../js/jquery.min.js"/>
                <script src="../js/jquery-csv.js"/>
                <script src="../js/transcript_firstp.js"/>
               <!-- <script type="text/javascript">
                </script>-->
            </head>        
            <body class="centered-wrapper">
                <div class="centered-content">
                    <xsl:choose>
                        <xsl:when test="not($CORPUSTITLE)">
                            <!-- parameter has not been supplied -->
                        </xsl:when>
                        <xsl:otherwise>
                            <!--parameter has been supplied -->
                        </xsl:otherwise>
                    </xsl:choose>
                    <xsl:choose>
                        <xsl:when test="not($TITLE)">
                            <!-- parameter has not been supplied -->
                        </xsl:when>
                        <xsl:otherwise>
                            <!--parameter has been supplied -->
                            <h3>
                                <xsl:attribute name="id">transcriptid</xsl:attribute>
                                <xsl:value-of select="$TITLE"/>
                            </h3>
                        </xsl:otherwise>
                    </xsl:choose>
                    <audio controls="true">
                        <xsl:attribute name="src">
                            <xsl:value-of select="$AUDIO"/>
                        </xsl:attribute>
                        <xsl:attribute name="id">audio</xsl:attribute> Your browser does not support
                        the audio element. </audio>              
           
                            <div class="annotationBlock">
                                <div class="annotationBlockPart">
                                    <button onclick="showdropdown()" class="dropbtn"
                                        >Annotations</button>
                                </div>
                                <div id="myDropdown" class="dropdown-content">
                                    <div onclick="showAnnotation(event)" id="non-standard"
                                        aria-checked="false">Non-standard/spoken</div>
                                    <div onclick="showAnnotation(event)" id="hesitation"
                                        aria-checked="false">Hesitations (äh)</div>
                                    <div onclick="showAnnotation(event)" id="elongation"
                                        aria-checked="false">Elongations</div>
                                    <div onclick="showAnnotation(event)" id="nichtbcms"
                                        aria-checked="false">Non BCMS</div>
                                    <div onclick="showAnnotation(event)" id="non_word"
                                        aria-checked="false">Non word</div>
                                    <div onclick="showAnnotation(event)" id="truncation"
                                        aria-checked="false">Truncations</div>
                                    <div onclick="showAnnotation(event)" id="stutter"
                                        aria-checked="false">Stutter</div>
                                    <div onclick="showAnnotation(event)" id="unclear"
                                        aria-checked="false">Unclear</div>
                                    <div id="abcd" onclick="showAllAnnotations(event)" class=""
                                        aria-checked="false">All annotations</div>
                                    <div onclick="exportAnnotations()">Export all annotations</div>
                                </div>
                                <div class="annotationBlockPart">
                                    <button id="annotieren" class="dropbtn">Annotate</button>
                                </div>
                                <div id="userInputInfo" hidden="true">
                                    <form>
                                        <div id="chooseTag">Tag: <input type="text" id="userInput" required="required" pattern="[a-zA-Z](\d|-|_|[a-zA-Z])*" maxlength="30" title="Tags can contain letters (A-Za-z), digits (0-9), hyphens (-), underscores (_), and be max. 30 char. long"/></div>
                                        
                                        <div id="chooseColor">Colour: <input type="color"
                                                id="annocolor" value="#e66465" required="required"
                                            /></div>
                                    </form>
                                    <div id="Send">
                                        <button onclick="exportUserAnnotationsCsv()">Export
                                            (csv)</button>
                                    </div>
                                </div>
                            </div>

                    <table id="transcript">
                        <thead>
                            <tr>
                                <th>Line</th>
                                <th>Speaker</th>
                                <th>Turn</th>
                            </tr>
                        </thead>
                        <tbody>
                            <xsl:apply-templates select="//u"/>
                        </tbody>
                    </table>
                </div>
            </body>
            
            <script src="../js/jquery.min.js"/>
            <script src="../js/transcript_secondp.js"/>
            <script type="text/javascript"><![CDATA[
                    //]]>
               </script>
    </html>
    </xsl:template>
    
    <xsl:template match="u">
        <tr>
            <td class="line" onclick="playme()">
                <xsl:variable name="LINE">
                    <xsl:value-of select="./@xml:id"/>
                </xsl:variable>
                <xsl:attribute name="id">
                    <xsl:value-of select="substring($LINE, 9)"/>
                </xsl:attribute>
                <!-- the line number ist taken from <u> id, since the index 9-->
                <!-- <xsl:value-of select="substring($LINE,9)"/>-->
                <xsl:text>&#xa;▶&#xa;</xsl:text>
                <xsl:value-of select="substring($LINE, 9)"/>
            </td>
            <td class="speaker">
                <xsl:if test="not(contains(./@who, 'Instr')) and ./@who != ''">
                    <xsl:attribute name="class">speaker participant</xsl:attribute>
                </xsl:if>
                <xsl:value-of select="substring(./@who, 2)"/>
            </td>
            <td class="text">
                <xsl:attribute name="id">
                    <xsl:value-of select="./@xml:id"/>
                </xsl:attribute>
                <xsl:attribute name="data-start">
                    <xsl:variable name="AUDIOSTARTREF">
                        <xsl:value-of select="./@start"/>
                    </xsl:variable>
                    <xsl:variable name="AUDIOSTART">
                        <xsl:value-of select="substring($AUDIOSTARTREF, 2)"/>
                    </xsl:variable>
                    <xsl:value-of select="//when[@xml:id = $AUDIOSTART]/@interval"/>
                </xsl:attribute>
                <xsl:attribute name="data-end">
                    <xsl:variable name="AUDIOENDREF">
                        <xsl:value-of select="./@end"/>
                    </xsl:variable>
                    <xsl:variable name="AUDIOEND">
                        <xsl:value-of select="substring($AUDIOENDREF, 2)"/>
                    </xsl:variable>
                    <xsl:value-of select="//when[@xml:id = $AUDIOEND]/@interval"/>
                </xsl:attribute>
                <xsl:apply-templates/>
            </td>
        </tr>
    </xsl:template>
    <xsl:template match="title">
        <h3/>
    </xsl:template>
    <xsl:template match="w">
        <span class="w">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:value-of select="."/>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="u/w[@norm]">
        <span class="w non-standard">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:attribute name="title">
                <xsl:value-of select="./@norm"/>
            </xsl:attribute>
            <xsl:value-of select="."/>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="unclear/w">
        <span class="w unclear" title="unclear word">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute> (<xsl:value-of select="."/>) </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="del">
        <xsl:choose>
            <xsl:when test="@type = 'stutter'">
                <span class="w stutter" title="stutter">
                    <xsl:attribute name="id">
                        <xsl:value-of select="./@xml:id"/>
                    </xsl:attribute>
                    <xsl:value-of select="."/>
                </span>
            </xsl:when>
            <xsl:when test="@type = 'truncation'">
                <span class="w truncation" title="truncated word">
                    <xsl:attribute name="id">
                        <xsl:value-of select="./@xml:id"/>
                    </xsl:attribute>
                    <xsl:value-of select="."/>
                </span>
            </xsl:when>
        </xsl:choose>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="seg[@type = 'non-bcms']/w">
        <span class="w nichtbcms" title="nichtbcms">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:value-of select="."/>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="seg[@type = 'non-word']/w">
        <span class="w non-word" title="non-word">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:value-of select="."/>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="seg[@type = 'elongation']/w">
        <span class="w elongation" title="hesitation (elongated segments)">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:value-of select="."/>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="seg[@type = 'hesitation']/w">
        <span class="w hesitation" title="hesitation (äh)">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:value-of select="."/>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="gap">
        <span class="gap" title="omitted segment">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:text>[...] </xsl:text>
        </span>
    </xsl:template>
    <xsl:template match="incident/desc">
        <span class="incident" title="incident">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute> ((<xsl:value-of select="."/>)) </span>
    </xsl:template>
    <xsl:template match="pause">
        <span class="pause" title="pause">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:choose>
                <xsl:when test="@type = 'micropause'">
                    <xsl:text>(.)</xsl:text>
                </xsl:when>
                <xsl:when test="@type = 'short'">
                    <xsl:text>(-)</xsl:text>
                </xsl:when>
                <xsl:when test="@type = 'middle'">
                    <xsl:text>(--)</xsl:text>
                </xsl:when>
                <xsl:when test="@type = 'long'">
                    <xsl:text>(---)</xsl:text>
                </xsl:when>
                <!--<xsl:otherwise>
                    <xsl:text>(</xsl:text>
                    <xsl:value-of select="@type"/>
                    <xsl:text>)</xsl:text>
                </xsl:otherwise>-->
            </xsl:choose>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
    <xsl:template match="vocal/desc">
        <span class="vocal" title="vocal">
            <xsl:attribute name="id">
                <xsl:value-of select="./@xml:id"/>
            </xsl:attribute>
            <xsl:choose>
                <xsl:when test=". = 'inhale (short)'">
                    <xsl:text>.h</xsl:text>
                </xsl:when>
                <xsl:when test=". = 'inhale (medium)'">
                    <xsl:text>.hh</xsl:text>
                </xsl:when>
                <xsl:when test=". = 'inhale (long)'">
                    <xsl:text>.hhh</xsl:text>
                </xsl:when>
                <xsl:when test=". = 'exhale (short)'">
                    <xsl:text>h.</xsl:text>
                </xsl:when>
                <xsl:when test=". = 'exhale (medium)'">
                    <xsl:text>hh.</xsl:text>
                </xsl:when>
                <xsl:when test=". = 'exhale (long)'">
                    <xsl:text>hhh.</xsl:text>
                </xsl:when>
                <xsl:when test=". = 'laugh'">
                    <xsl:text>:-D</xsl:text>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:text>((</xsl:text>
                    <xsl:value-of select="."/>
                    <xsl:text>))</xsl:text>
                </xsl:otherwise>
            </xsl:choose>
        </span>
        <xsl:text> </xsl:text>
    </xsl:template>
</xsl:stylesheet>

